# DBT Documentor (Python Version)

Automatically generate docs for undocumented DBT models.

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Documentation](#documentation)
- [Contributing](#contributing)
- [License](#license)

## Installation

To install the package, run the following command:

```bash
pip install dbt-doc-py
```

## Usage
Place inside of the DBT project folder and run this command:

```
dbt-doc-py
```

You can execute it from other directories, this way:

```
dbt-doc-py --working-directory /folder/DBTproject
```

TO-DO: Finish README file:

## Documentation


## Contributing


## License
This project is licensed under the MIT License. See the LICENSE file for details.
